
<#
Xml examples 

File watch
<root>
    <file>
        <path>c:\temp.tmp</path>
        <process>1</process>
    </file>
</root>

Registry watch
<root>
    <registry>
        <key>HKCU\Software\Tweakeze\test</key>
        <name>MyValue</name>
        <value>1</value>
        <process>1</process>
    </registry>
</root>

#>

function OnItem
{
    param ($Context)

    $xml = New-Object -TypeName System.Xml.XmlDocument
    $xml.LoadXml($Context)

    #$child = $xml.CreateElement("process")
    #$text = $xml.CreateTextNode("1")
    #$child.AppendChild($text);

    $res = ""

    if ($xml.root.file){
        $res = OnFile $xml
    }

    if ($xml.root.registry){
        $res = OnRegistry $xml
    }
    
    return $res
}

function OnFile 
{
    param($xml)
        
    if ($xml.root.file){
        $xml.root.file.process = "1"
    }

    return $Xml
}

function FormatXml([xml]$xml)
{
    $StringWriter = New-Object System.IO.StringWriter;
    $XmlWriter = New-Object System.Xml.XmlTextWriter $StringWriter;
    $XmlWriter.Formatting = "indented";
    $xml.WriteTo($XmlWriter);
    $XmlWriter.Flush();
    $StringWriter.Flush();
    return $StringWriter.ToString();
}

function OnRegistry
{
    param($xml)
        
    if ($xml.root.registry){
        $xml.root.registry.process = "1"
        $xmlFormatted = FormatXml($xml)
        #$res = [System.Windows.Forms.Messagebox]::Show($xmlFormatted,'Powershell OnRegistry')
    }		

	return $xml
}


function OnFix
{

    param ($Context)

    $xml = New-Object -TypeName System.Xml.XmlDocument
    $xml.LoadXml($Context)
    
   
    if ($xml.root.file){
    
        $Ext = [System.IO.Path]::GetExtension($xml.root.file.path)
		
	    if ($Ext -eq ".tmp"){
			#allow fixing for "tmp" files only
		    $xml.root.file.process = "1"
	    }Else{
		    $xml.root.file.process = "0"
	    }
    }

    if ($xml.root.registry){
		#uncomment to disallow fixing
        #$xml.root.registry.process = "0"
		
		#allow fixing
		$xml.root.registry.process = "0"
    }
    
    return $xml
}	

<#
File Change Notification
<root>
    <file>
        <path>c:\temp.tmp</path>
        <notify>1<notify>
    </file>
</root>

Notification Change type <notify>
Add 				= 1		==>The file was added to the directory.
Removed 			= 2 	==>The file was removed from the directory. When a file is renamed to a different directory the client will receive this notification along with MODIFIED.
Modified 			= 3		==> The file was modified. This can be a change to the data or attributes of the file. When a file is renamed to a different directory the client will receive this notification along with REMOVED.
Renamed_Old_Name	= 4 	==>The file was renamed, and this is the old name. This notification is only sent when the rename operation does not change the directory the file resides in. The client will also receive a RENAMED_NEW_NAME notification. This notification will not be received if the file is renamed to a different directory.
Renamed_New_Name	= 5 	==>The file was renamed, and this is the new name. This notification is only sent when the rename operation does not change the directory the file resides in. The client will also receive a RENAME_OLD_NAME notification. This notification will not be received if the file is renamed to a different directory.
#>

function OnChange
{
    param ($Context)

    $xml = New-Object -TypeName System.Xml.XmlDocument
    $xml.LoadXml($Context)
    
    $type = $xml.root.file.notify
    $Filename = $xml.root.file.path
	
	if ($type -eq 2){
		#[System.Windows.Forms.Messagebox]::Show($Filename,'Powershell - File Deleted')
	}
	if ($type -eq 1){
		#[System.Windows.Forms.Messagebox]::Show($Filename,'Powershell - File Added')
	}
}



